==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/themes/advanced/langs/fr.js <==
tinyMCE.addI18n('fr.advanced',{
style_select:"Styles",
font_size:"Taille de la police",
fontdefault:"Famille de police",
block:"Format",
paragraph:"Paragraphe",
div:"Div",
address:"Adresse",
pre:"Preformatt\u00E9",
h1:"Titre 1",
h2:"Titre 2",
h3:"Titre 3",
h4:"Titre 4",
h5:"Titre 5",
h6:"Titre 6",
blockquote:"Citation",
code:"Code",
samp:"Exemple de code",
dt:"Terme \u00E0 d\u00E9finir",
dd:"D\u00E9finition du terme",
bold_desc:"Gras (Ctrl+B)",
italic_desc:"Italique (Ctrl+I)",
underline_desc:"Soulign\u00E9 (Ctrl+U)",
striketrough_desc:"Barr\u00E9",
justifyleft_desc:"Align\u00E9 \u00E0 gauche",
justifycenter_desc:"Centr\u00E9",
justifyright_desc:"Align\u00E9 \u00E0 droite",
justifyfull_desc:"Justifi\u00E9",
bullist_desc:"Liste non-num\u00E9rot\u00E9e",
numlist_desc:"Liste num\u00E9rot\u00E9e",
outdent_desc:"Retirer l'indentation",
indent_desc:"Indenter",
undo_desc:"D\u00E9faire (Ctrl+Z)",
redo_desc:"Refaire (Ctrl+Y)",
link_desc:"Ins\u00E9rer/\u00C9diter le lien",
unlink_desc:"D\u00E9lier",
image_desc:"Ins\u00E9rer/\u00C9diter l'image",
cleanup_desc:"Nettoyer le code non propre",
code_desc:"\u00C9diter source HTML",
sub_desc:"Indice",
sup_desc:"Exposant",
hr_desc:"Ins\u00E9rer trait horizontal",
removeformat_desc:"Enlever formattage",
custom1_desc:"Votre description personnalis\u00E9e ici",
forecolor_desc:"Choisir la couleur du texte",
backcolor_desc:"Choisir la couleur de surlignage",
charmap_desc:"Ins\u00E9rer caract\u00E8res sp\u00E9ciaux",
visualaid_desc:"Activer/d\u00E9sactiver les guides et les \u00E9l\u00E9ments invisibles",
anchor_desc:"Ins\u00E9rer/\u00C9diter ancre",
cut_desc:"Couper",
copy_desc:"Copier",
paste_desc:"Coller",
image_props_desc:"Propri\u00E9t\u00E9s de l'image",
newdocument_desc:"Nouveau document",
help_desc:"Aide",
blockquote_desc:"Citation",
clipboard_msg:"Copier/Couper/Coller n'est pas disponible sous Mozilla et sous Firefox.\n\r\n      Voulez-vous plus d'information sur ce probl\u00E8me\u00A0?",
path:"Chemin",
newdocument:"\u00CAtes-vous s\u00FBr de vouloir effacer l'enti\u00E8ret\u00E9 du document\u00A0?",
toolbar_focus:"Aller aux boutons de l'\u00E9diteur - Alt+Q, Aller \u00E0 l'\u00E9diteur - Alt-Z, Aller au chemin de l'\u00E9l\u00E9ment - Alt-X",
more_colors:"Plus de couleurs"
});

==> ikaaro-0.50.5.tar.gz: ikaaro-0.50.5/ui/tiny_mce/themes/advanced/langs/fr.js <==
tinyMCE.addI18n('fr.advanced',{
style_select:"Styles",
font_size:"Taille de la police",
fontdefault:"Famille de police",
block:"Format",
paragraph:"Paragraphe",
div:"Div",
address:"Adresse",
pre:"Preformatt\u00E9",
h1:"Titre 1",
h2:"Titre 2",
h3:"Titre 3",
h4:"Titre 4",
h5:"Titre 5",
h6:"Titre 6",
blockquote:"Citation",
code:"Code",
samp:"Exemple de code",
dt:"Terme \u00E0 d\u00E9finir",
dd:"D\u00E9finition du terme",
bold_desc:"Gras (Ctrl+B)",
italic_desc:"Italique (Ctrl+I)",
underline_desc:"Soulign\u00E9 (Ctrl+U)",
striketrough_desc:"Barr\u00E9",
justifyleft_desc:"Align\u00E9 \u00E0 gauche",
justifycenter_desc:"Centr\u00E9",
justifyright_desc:"Align\u00E9 \u00E0 droite",
justifyfull_desc:"Justifi\u00E9",
bullist_desc:"Liste non-num\u00E9rot\u00E9e",
numlist_desc:"Liste num\u00E9rot\u00E9e",
outdent_desc:"Retirer l'indentation",
indent_desc:"Indenter",
undo_desc:"Annuler (Ctrl+Z)",
redo_desc:"R\u00E9tablir (Ctrl+Y)",
link_desc:"Ins\u00E9rer/\u00C9diter le lien",
unlink_desc:"D\u00E9lier",
image_desc:"Ins\u00E9rer/\u00C9diter l'image",
cleanup_desc:"Nettoyer le code non propre",
code_desc:"\u00C9diter source HTML",
sub_desc:"Indice",
sup_desc:"Exposant",
hr_desc:"Ins\u00E9rer trait horizontal",
removeformat_desc:"Enlever formattage",
custom1_desc:"Votre description personnalis\u00E9e ici",
forecolor_desc:"Choisir la couleur du texte",
backcolor_desc:"Choisir la couleur de surlignage",
charmap_desc:"Ins\u00E9rer caract\u00E8res sp\u00E9ciaux",
visualaid_desc:"Activer/d\u00E9sactiver les guides et les \u00E9l\u00E9ments invisibles",
anchor_desc:"Ins\u00E9rer/\u00C9diter ancre",
cut_desc:"Couper",
copy_desc:"Copier",
paste_desc:"Coller",
image_props_desc:"Propri\u00E9t\u00E9s de l'image",
newdocument_desc:"Nouveau document",
help_desc:"Aide",
blockquote_desc:"Citation",
clipboard_msg:"Copier/Couper/Coller n'est pas disponible sous Mozilla et sous Firefox.\n\r\n      Voulez-vous plus d'information sur ce probl\u00E8me\u00A0?",
path:"Chemin",
newdocument:"\u00CAtes-vous s\u00FBr de vouloir effacer l'enti\u00E8ret\u00E9 du document\u00A0?",
toolbar_focus:"Aller aux boutons de l'\u00E9diteur - Alt+Q, Aller \u00E0 l'\u00E9diteur - Alt-Z, Aller au chemin de l'\u00E9l\u00E9ment - Alt-X",
more_colors:"Plus de couleurs"
});
